@@ -2,7 +2,7 @@
 /*  
     VTun - Virtual Tunnel over TCP/IP network.
 
-    Copyright (C) 1998,1999  Maxim Krasnyansky <max_mk@yahoo.com>
+    Copyright (C) 1998-2000  Maxim Krasnyansky <max_mk@yahoo.com>
 
     VTun has been derived from VPPP package by Maxim Krasnyansky. 
 
@@ -18,7 +18,7 @@
  */
 
 /*
- * Version: 2.0 12/30/1999 Maxim Krasnyansky <max_mk@yahoo.com>
+ * $Id: lfd_encrypt.c,v 1.2 2000/05/13 23:55:57 maxk Exp $
  */ 
 
 /*
@@ -57,7 +57,7 @@ int alloc_encrypt(struct vtun_host *host)
 
    BF_set_key(&key, ENC_KEY_SIZE, MD5(host->passwd,strlen(host->passwd),NULL));
 
-   syslog(LOG_INFO, "Encryption initialized.");
+   syslog(LOG_INFO, "BlowFish encryption initialized");
    return 0;
 }
 
