@@ -2,7 +2,7 @@
 /*  
     VTun - Virtual Tunnel over TCP/IP network.
 
-    Copyright (C) 1998,1999  Maxim Krasnyansky <max_mk@yahoo.com>
+    Copyright (C) 1998-2000  Maxim Krasnyansky <max_mk@yahoo.com>
 
     VTun has been derived from VPPP package by Maxim Krasnyansky. 
 
@@ -18,9 +18,12 @@
  */
 
 /*
- * Version: 2.0 12/30/1999 Maxim Krasnyansky <max_mk@yahoo.com>
+ * $Id: llist.h,v 1.1.1.2 2000/03/28 17:19:30 maxk Exp $
  */ 
 
+#ifndef _VTUN_LLIST_H
+#define _VTUN_LLIST_H
+
 struct llist_element {
 	struct llist_element * next;
 	void * data;
@@ -39,3 +42,6 @@ int  llist_empty(llist *l);
 void * llist_trav(llist *l, int (*f)(void *d, void *u), void *u);
 int llist_copy(llist *l, llist *t, void* (*f)(void *d, void *u), void *u);
 void * llist_free(llist *l, int (*f)(void *d, void *u), void *u);
+
+
+#endif /* _VTUN_LLIST_H */
