@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: netlib.c,v 1.6 2000/05/13 23:55:57 maxk Exp $
+ * $Id: netlib.c,v 1.7 2000/05/30 20:40:02 maxk Exp $
  */ 
 
 #include "config.h"
@@ -124,7 +124,9 @@ unsigned long getifaddr(char * ifname)
      if( (s = socket(AF_INET, SOCK_DGRAM, 0)) == -1 )
         return -1;
 
-     strcpy(ifr.ifr_name, ifname);
+     strncpy(ifr.ifr_name, ifname, sizeof(ifr.ifr_name)-1);
+     ifr.ifr_name[sizeof(ifr.ifr_name)-1]='\0';
+
      if( ioctl(s, SIOCGIFADDR, &ifr) < 0 ){
         close(s);
         return -1;
