@@ -17,7 +17,7 @@
  */
 
 /*
- * $Id: vtun.h,v 1.6 2000/05/03 16:16:42 maxk Exp $
+ * $Id: vtun.h,v 1.7 2000/05/30 20:40:02 maxk Exp $
  */ 
 #ifndef _VTUN_H
 #define _VTUN_H
@@ -38,6 +38,9 @@
 
 /* Statistic interval in seconds */
 #define VTUN_STAT_IVAL  5*60  /* 5 min */
+
+/* Max lenght of device name */
+#define VTUN_DEV_LEN  20 
  
 /* End of configurable part */
 
